@@ -4,11 +4,12 @@ from ..action import ActionManager as AM
 from ..cloud import CloudCli
 from ..errors import ProjectError
 from ..project import Project
+from .. import __edb_ansible_version__
 
 
 class AWSPOTProject(Project):
 
-    ansible_collection_name = 'edb_devops.edb_postgres:3.5.2'
+    ansible_collection_name = 'edb_devops.edb_postgres:%s' % __edb_ansible_version__  # noqa
     aws_collection_name = 'community.aws:1.4.0'
 
     def __init__(self, name, env, bin_path=None):
@@ -17,6 +18,8 @@ class AWSPOTProject(Project):
         self.terraform_path = os.path.join(self.terraform_share_path, 'aws')
         # POT only attributes
         self.ansible_pot_role = os.path.join(self.ansible_share_path, 'roles')
+        # Route53 entry removal playbook
+        self.ansible_route53_remove = os.path.join(self.ansible_share_path, 'POT-Remove-Project-Route53.yml')
         # TPAexec hooks path
         self.tpaexec_pot_hooks = os.path.join(self.tpaexec_share_path, 'hooks')
         self.custom_ssh_keys = {}
@@ -180,3 +183,5 @@ class AWSPOTProject(Project):
     def display_inventory(self, inventory_data):
         self.pot_display_inventory(inventory_data)
 
+    def destroy(self):
+        self.pot_destroy()
